==> jc-1.4.0.tar.gz: javax/swing/JSpinner__24NumberEditor.h <==
// public class javax.swing.JSpinner$NumberEditor

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 7efa272e334599d4 javax_swing_JSpinner__24DefaultEditor
// @dep_class fb91cc482419dbae javax_swing_JSpinner__24NumberEditor

// header file dependencies
// @dep_header javax_swing_JSpinner__24DefaultEditor

#include "javax/swing/JSpinner__24DefaultEditor.h"

#ifndef _JC_javax_swing_JSpinner__24NumberEditor_H_
#define _JC_javax_swing_JSpinner__24NumberEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_DecimalFormat$object;
struct _jc_javax_swing_JSpinner$object;
struct _jc_javax_swing_SpinnerNumberModel$object;

// Typedefs
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$sub_refs	_jc_javax_swing_JSpinner__24NumberEditor$sub_refs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs	_jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$refs	_jc_javax_swing_JSpinner__24NumberEditor$refs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$nonrefs	_jc_javax_swing_JSpinner__24NumberEditor$nonrefs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$object	_jc_javax_swing_JSpinner__24NumberEditor$object;

typedef struct _jc_javax_swing_JSpinner__24NumberEditor$fields_struct	_jc_javax_swing_JSpinner__24NumberEditor$fields_struct;
typedef const struct _jc_javax_swing_JSpinner__24NumberEditor$vmethods	_jc_javax_swing_JSpinner__24NumberEditor$vmethods;
typedef const struct _jc_javax_swing_JSpinner__24NumberEditor$vtable	_jc_javax_swing_JSpinner__24NumberEditor$vtable;
typedef const struct _jc_javax_swing_JSpinner__24NumberEditor$vtype	_jc_javax_swing_JSpinner__24NumberEditor$vtype;

// Class fields structure
struct _jc_javax_swing_JSpinner__24NumberEditor$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JSpinner__24NumberEditor$fields_struct _jc_javax_swing_JSpinner__24NumberEditor$class_fields;

// Constructors
extern void _jc_javax_swing_JSpinner__24NumberEditor$method$_init$e4c5e17f45ff705d(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *, struct _jc_javax_swing_JSpinner$object *);
extern void _jc_javax_swing_JSpinner__24NumberEditor$method$_init$9ccce43982836960(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *, struct _jc_javax_swing_JSpinner$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_text_DecimalFormat$object *_jc_javax_swing_JSpinner__24NumberEditor$method$getFormat$b1276393935fe430(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *);
extern struct _jc_javax_swing_SpinnerNumberModel$object *_jc_javax_swing_JSpinner__24NumberEditor$method$getModel$8c310be496b817fe(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JSpinner__24NumberEditor$method_info$getFormat$b1276393935fe430;
extern _jc_method _jc_javax_swing_JSpinner__24NumberEditor$method_info$getModel$8c310be496b817fe;

// Virtual methods structure
struct _jc_javax_swing_JSpinner__24NumberEditor$vmethods {
	struct _jc_java_text_DecimalFormat$object	*(*getFormat$b1276393935fe430)(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *);
	struct _jc_javax_swing_SpinnerNumberModel$object	*(*getModel$8c310be496b817fe)(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *);
};

// Vtable
struct _jc_javax_swing_JSpinner__24NumberEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_JSpinner__24DefaultEditor$vmethods	javax_swing_JSpinner__24DefaultEditor;
	_jc_javax_swing_JSpinner__24NumberEditor$vmethods	javax_swing_JSpinner__24NumberEditor;
};

// Vtype
struct _jc_javax_swing_JSpinner__24NumberEditor$vtype {
	_jc_type			type;
	_jc_javax_swing_JSpinner__24NumberEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24NumberEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JSpinner__24NumberEditor$refs {
    _jc_javax_swing_JSpinner__24NumberEditor$sub_refs	javax_swing_JSpinner__24NumberEditor;
    _jc_javax_swing_JSpinner__24DefaultEditor$sub_refs	javax_swing_JSpinner__24DefaultEditor;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JSpinner__24NumberEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_JSpinner__24DefaultEditor$sub_nonrefs	javax_swing_JSpinner__24DefaultEditor;
    _jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs	javax_swing_JSpinner__24NumberEditor;
};

// Object instance structure
struct _jc_javax_swing_JSpinner__24NumberEditor$object {
	_jc_javax_swing_JSpinner__24NumberEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JSpinner__24NumberEditor$vtype	*vtype;
	_jc_javax_swing_JSpinner__24NumberEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JSpinner__24NumberEditor$vtype _jc_javax_swing_JSpinner__24NumberEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JSpinner__24NumberEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JSpinner__24NumberEditor$class_object;

#endif	/* _JC_javax_swing_JSpinner__24NumberEditor_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JSpinner__24NumberEditor.h <==
// public class javax.swing.JSpinner$NumberEditor

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 7efa272e334599d4 javax_swing_JSpinner__24DefaultEditor
// @dep_class fb91cc482419dbae javax_swing_JSpinner__24NumberEditor

// header file dependencies
// @dep_header javax_swing_JSpinner__24DefaultEditor

#include "javax/swing/JSpinner__24DefaultEditor.h"

#ifndef _JC_javax_swing_JSpinner__24NumberEditor_H_
#define _JC_javax_swing_JSpinner__24NumberEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_DecimalFormat$object;
struct _jc_javax_swing_JSpinner$object;
struct _jc_javax_swing_SpinnerNumberModel$object;

// Typedefs
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$sub_refs	_jc_javax_swing_JSpinner__24NumberEditor$sub_refs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs	_jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$refs	_jc_javax_swing_JSpinner__24NumberEditor$refs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$nonrefs	_jc_javax_swing_JSpinner__24NumberEditor$nonrefs;
typedef struct _jc_javax_swing_JSpinner__24NumberEditor$object	_jc_javax_swing_JSpinner__24NumberEditor$object;

typedef struct _jc_javax_swing_JSpinner__24NumberEditor$fields_struct	_jc_javax_swing_JSpinner__24NumberEditor$fields_struct;
typedef const struct _jc_javax_swing_JSpinner__24NumberEditor$vmethods	_jc_javax_swing_JSpinner__24NumberEditor$vmethods;
typedef const struct _jc_javax_swing_JSpinner__24NumberEditor$vtable	_jc_javax_swing_JSpinner__24NumberEditor$vtable;
typedef const struct _jc_javax_swing_JSpinner__24NumberEditor$vtype	_jc_javax_swing_JSpinner__24NumberEditor$vtype;

// Class fields structure
struct _jc_javax_swing_JSpinner__24NumberEditor$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JSpinner__24NumberEditor$fields_struct _jc_javax_swing_JSpinner__24NumberEditor$class_fields;

// Constructors
extern void _jc_javax_swing_JSpinner__24NumberEditor$method$_init$e4c5e17f45ff705d(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *, struct _jc_javax_swing_JSpinner$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JSpinner__24NumberEditor$method$_init$9ccce43982836960(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *, struct _jc_javax_swing_JSpinner$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_text_DecimalFormat$object *_jc_javax_swing_JSpinner__24NumberEditor$method$getFormat$b1276393935fe430(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_SpinnerNumberModel$object *_jc_javax_swing_JSpinner__24NumberEditor$method$getModel$8c310be496b817fe(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JSpinner__24NumberEditor$method_info$getFormat$b1276393935fe430;
extern _jc_method _jc_javax_swing_JSpinner__24NumberEditor$method_info$getModel$8c310be496b817fe;

// Virtual methods structure
struct _jc_javax_swing_JSpinner__24NumberEditor$vmethods {
	struct _jc_java_text_DecimalFormat$object	*(*getFormat$b1276393935fe430)(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_SpinnerNumberModel$object	*(*getModel$8c310be496b817fe)(_jc_env *, struct _jc_javax_swing_JSpinner__24NumberEditor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JSpinner__24NumberEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_JSpinner__24DefaultEditor$vmethods	javax_swing_JSpinner__24DefaultEditor;
	_jc_javax_swing_JSpinner__24NumberEditor$vmethods	javax_swing_JSpinner__24NumberEditor;
};

// Vtype
struct _jc_javax_swing_JSpinner__24NumberEditor$vtype {
	_jc_type			type;
	_jc_javax_swing_JSpinner__24NumberEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24NumberEditor$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JSpinner__24NumberEditor$refs {
    _jc_javax_swing_JSpinner__24NumberEditor$sub_refs	javax_swing_JSpinner__24NumberEditor;
    _jc_javax_swing_JSpinner__24DefaultEditor$sub_refs	javax_swing_JSpinner__24DefaultEditor;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JSpinner__24NumberEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_JSpinner__24DefaultEditor$sub_nonrefs	javax_swing_JSpinner__24DefaultEditor;
    _jc_javax_swing_JSpinner__24NumberEditor$sub_nonrefs	javax_swing_JSpinner__24NumberEditor;
};

// Object instance structure
struct _jc_javax_swing_JSpinner__24NumberEditor$object {
	_jc_javax_swing_JSpinner__24NumberEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JSpinner__24NumberEditor$vtype	*vtype;
	_jc_javax_swing_JSpinner__24NumberEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JSpinner__24NumberEditor$vtype _jc_javax_swing_JSpinner__24NumberEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JSpinner__24NumberEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JSpinner__24NumberEditor$class_object;

#endif	/* _JC_javax_swing_JSpinner__24NumberEditor_H_ */
